@@ -2,12 +2,30 @@ package JavaScript::Code::Expression;
 
 use strict;
 use vars qw[ $VERSION ];
+use base qw[
+  JavaScript::Code::Accessor
+  JavaScript::Code::Value
+];
 
-$VERSION = '0.01';
+__PACKAGE__->mk_ro_accessors(qw[ tree ]);
+
+$VERSION = '0.02';
 
 =head1 NAME
 
-JavaScript::Code::Expression - a javascript expression
+JavaScript::Code::Expression - A JavaScript Expression
+
+=head1 DESCRIPTION
+
+A Expression Class
+
+=head1 METHODS
+
+=head2 $self->tree( )
+
+Returns a tree of L<JavaScript::Code::Expression::Op>'s
+
+=cut
 
 =head1 SEE ALSO
 
@@ -25,7 +43,3 @@ the same terms as Perl itself.
 =cut
 
 1;
-
-
-
-1;
\ No newline at end of file
